# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class TransactionDirectPostRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "dc_sign",
            "force_post",
            "reference_id",
            "subtype",
            "effective_date",
            "memo",
            "transaction_time",
            "currency",
            "info_only",
            "type",
            "network",
        }
        
        class properties:
            
            
            class amount(
                schemas.Int64Schema
            ):
            
            
                class MetaOapg:
                    format = 'int64'
                    inclusive_minimum = 0
            currency = schemas.StrSchema
        
            @staticmethod
            def dc_sign() -> typing.Type['DcSign']:
                return DcSign
            effective_date = schemas.DateTimeSchema
            force_post = schemas.BoolSchema
            info_only = schemas.BoolSchema
            memo = schemas.StrSchema
            network = schemas.StrSchema
            reference_id = schemas.StrSchema
            subtype = schemas.StrSchema
            transaction_time = schemas.DateTimeSchema
            type = schemas.StrSchema
            account_alias = schemas.StrSchema
            account_id = schemas.StrSchema
            account_no = schemas.StrSchema
            description = schemas.StrSchema
            
            
            class enhanced_transaction(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'enhanced_transaction':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class external_data(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'external_data':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            offset_description = schemas.StrSchema
            
            
            class risk_info(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'risk_info':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class user_data(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'user_data':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            uuid = schemas.UUIDSchema
            __annotations__ = {
                "amount": amount,
                "currency": currency,
                "dc_sign": dc_sign,
                "effective_date": effective_date,
                "force_post": force_post,
                "info_only": info_only,
                "memo": memo,
                "network": network,
                "reference_id": reference_id,
                "subtype": subtype,
                "transaction_time": transaction_time,
                "type": type,
                "account_alias": account_alias,
                "account_id": account_id,
                "account_no": account_no,
                "description": description,
                "enhanced_transaction": enhanced_transaction,
                "external_data": external_data,
                "offset_description": offset_description,
                "risk_info": risk_info,
                "user_data": user_data,
                "uuid": uuid,
            }
    
    amount: MetaOapg.properties.amount
    dc_sign: 'DcSign'
    force_post: MetaOapg.properties.force_post
    reference_id: MetaOapg.properties.reference_id
    subtype: MetaOapg.properties.subtype
    effective_date: MetaOapg.properties.effective_date
    memo: MetaOapg.properties.memo
    transaction_time: MetaOapg.properties.transaction_time
    currency: MetaOapg.properties.currency
    info_only: MetaOapg.properties.info_only
    type: MetaOapg.properties.type
    network: MetaOapg.properties.network
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["info_only"]) -> MetaOapg.properties.info_only: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reference_id"]) -> MetaOapg.properties.reference_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_alias"]) -> MetaOapg.properties.account_alias: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_no"]) -> MetaOapg.properties.account_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enhanced_transaction"]) -> MetaOapg.properties.enhanced_transaction: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["external_data"]) -> MetaOapg.properties.external_data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["offset_description"]) -> MetaOapg.properties.offset_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["risk_info"]) -> MetaOapg.properties.risk_info: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_data"]) -> MetaOapg.properties.user_data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["uuid"]) -> MetaOapg.properties.uuid: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "currency", "dc_sign", "effective_date", "force_post", "info_only", "memo", "network", "reference_id", "subtype", "transaction_time", "type", "account_alias", "account_id", "account_no", "description", "enhanced_transaction", "external_data", "offset_description", "risk_info", "user_data", "uuid", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["info_only"]) -> MetaOapg.properties.info_only: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reference_id"]) -> MetaOapg.properties.reference_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_alias"]) -> typing.Union[MetaOapg.properties.account_alias, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_no"]) -> typing.Union[MetaOapg.properties.account_no, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enhanced_transaction"]) -> typing.Union[MetaOapg.properties.enhanced_transaction, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["external_data"]) -> typing.Union[MetaOapg.properties.external_data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["offset_description"]) -> typing.Union[MetaOapg.properties.offset_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["risk_info"]) -> typing.Union[MetaOapg.properties.risk_info, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_data"]) -> typing.Union[MetaOapg.properties.user_data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["uuid"]) -> typing.Union[MetaOapg.properties.uuid, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "currency", "dc_sign", "effective_date", "force_post", "info_only", "memo", "network", "reference_id", "subtype", "transaction_time", "type", "account_alias", "account_id", "account_no", "description", "enhanced_transaction", "external_data", "offset_description", "risk_info", "user_data", "uuid", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        dc_sign: 'DcSign',
        force_post: typing.Union[MetaOapg.properties.force_post, bool, ],
        reference_id: typing.Union[MetaOapg.properties.reference_id, str, ],
        subtype: typing.Union[MetaOapg.properties.subtype, str, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, datetime, ],
        memo: typing.Union[MetaOapg.properties.memo, str, ],
        transaction_time: typing.Union[MetaOapg.properties.transaction_time, str, datetime, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        info_only: typing.Union[MetaOapg.properties.info_only, bool, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        account_alias: typing.Union[MetaOapg.properties.account_alias, str, schemas.Unset] = schemas.unset,
        account_id: typing.Union[MetaOapg.properties.account_id, str, schemas.Unset] = schemas.unset,
        account_no: typing.Union[MetaOapg.properties.account_no, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        enhanced_transaction: typing.Union[MetaOapg.properties.enhanced_transaction, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        external_data: typing.Union[MetaOapg.properties.external_data, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        offset_description: typing.Union[MetaOapg.properties.offset_description, str, schemas.Unset] = schemas.unset,
        risk_info: typing.Union[MetaOapg.properties.risk_info, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        user_data: typing.Union[MetaOapg.properties.user_data, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        uuid: typing.Union[MetaOapg.properties.uuid, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TransactionDirectPostRequest':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            dc_sign=dc_sign,
            force_post=force_post,
            reference_id=reference_id,
            subtype=subtype,
            effective_date=effective_date,
            memo=memo,
            transaction_time=transaction_time,
            currency=currency,
            info_only=info_only,
            type=type,
            network=network,
            account_alias=account_alias,
            account_id=account_id,
            account_no=account_no,
            description=description,
            enhanced_transaction=enhanced_transaction,
            external_data=external_data,
            offset_description=offset_description,
            risk_info=risk_info,
            user_data=user_data,
            uuid=uuid,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.dc_sign import DcSign



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class OriginalCreditRequestModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "mid",
            "type",
            "card_id",
        }
        
        class properties:
            amount = schemas.IntSchema
            card_id = schemas.UUIDSchema
            
            
            class mid(
                schemas.StrSchema
            ):
                pass
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ACCOUNT_TO_ACCOUNT(cls):
                    return cls("account_to_account")
                
                @schemas.classproperty
                def PERSON_TO_PERSON(cls):
                    return cls("person_to_person")
                
                @schemas.classproperty
                def PREPAID(cls):
                    return cls("prepaid")
                
                @schemas.classproperty
                def WALLET_TRANSFER(cls):
                    return cls("wallet_transfer")
                
                @schemas.classproperty
                def MONEY_TRANSFER_BY_BANK(cls):
                    return cls("money_transfer_by_bank")
                
                @schemas.classproperty
                def BUSINESS_TO_BUSINESS(cls):
                    return cls("business_to_business")
                
                @schemas.classproperty
                def DISBURSEMENT(cls):
                    return cls("disbursement")
                
                @schemas.classproperty
                def GOVERNMENT_DISBURSEMENT(cls):
                    return cls("government_disbursement")
                
                @schemas.classproperty
                def GAMBLING_PAYOUT(cls):
                    return cls("gambling_payout")
                
                @schemas.classproperty
                def LOYALTY(cls):
                    return cls("loyalty")
                
                @schemas.classproperty
                def MERCHANT_DISBURSEMENT(cls):
                    return cls("merchant_disbursement")
                
                @schemas.classproperty
                def ONLINE_GAMBLING_PAYOUT(cls):
                    return cls("online_gambling_payout")
                
                @schemas.classproperty
                def PENSION_DISBURSEMENT(cls):
                    return cls("pension_disbursement")
                
                @schemas.classproperty
                def PREPAID_LOADS(cls):
                    return cls("prepaid_loads")
                
                @schemas.classproperty
                def CARD_BILL_PAYMENT(cls):
                    return cls("card_bill_payment")
                
                @schemas.classproperty
                def BILL_PAYMENT(cls):
                    return cls("bill_payment")
                
                @schemas.classproperty
                def CASH_CLAIM(cls):
                    return cls("cash_claim")
                
                @schemas.classproperty
                def CASH_IN(cls):
                    return cls("cash_in")
                
                @schemas.classproperty
                def CASH_OUT(cls):
                    return cls("cash_out")
                
                @schemas.classproperty
                def MOBILE_AIR_TIME_PAYMENT(cls):
                    return cls("mobile_air_time_payment")
                
                @schemas.classproperty
                def MONEY_TRANSFER_BY_MERCHANT(cls):
                    return cls("money_transfer_by_merchant")
                
                @schemas.classproperty
                def FACE_TO_FACE_MERCHANT_PAYMENT(cls):
                    return cls("face_to_face_merchant_payment")
                
                @schemas.classproperty
                def GOVERNMENT_PAYMENT(cls):
                    return cls("government_payment")
                
                @schemas.classproperty
                def PAYMENTS_GOODS_SERVICES(cls):
                    return cls("payments_goods_services")
        
            @staticmethod
            def card_acceptor() -> typing.Type['CardAcceptorModel']:
                return CardAcceptorModel
            screening_score = schemas.StrSchema
        
            @staticmethod
            def sender_data() -> typing.Type['OriginalCreditSenderData']:
                return OriginalCreditSenderData
            transactionPurpose = schemas.StrSchema
            __annotations__ = {
                "amount": amount,
                "card_id": card_id,
                "mid": mid,
                "type": type,
                "card_acceptor": card_acceptor,
                "screening_score": screening_score,
                "sender_data": sender_data,
                "transactionPurpose": transactionPurpose,
            }
    
    amount: MetaOapg.properties.amount
    mid: MetaOapg.properties.mid
    type: MetaOapg.properties.type
    card_id: MetaOapg.properties.card_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["card_id"]) -> MetaOapg.properties.card_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mid"]) -> MetaOapg.properties.mid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["card_acceptor"]) -> 'CardAcceptorModel': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["screening_score"]) -> MetaOapg.properties.screening_score: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_data"]) -> 'OriginalCreditSenderData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionPurpose"]) -> MetaOapg.properties.transactionPurpose: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "card_id", "mid", "type", "card_acceptor", "screening_score", "sender_data", "transactionPurpose", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["card_id"]) -> MetaOapg.properties.card_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mid"]) -> MetaOapg.properties.mid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["card_acceptor"]) -> typing.Union['CardAcceptorModel', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["screening_score"]) -> typing.Union[MetaOapg.properties.screening_score, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_data"]) -> typing.Union['OriginalCreditSenderData', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionPurpose"]) -> typing.Union[MetaOapg.properties.transactionPurpose, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "card_id", "mid", "type", "card_acceptor", "screening_score", "sender_data", "transactionPurpose", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        mid: typing.Union[MetaOapg.properties.mid, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        card_id: typing.Union[MetaOapg.properties.card_id, str, uuid.UUID, ],
        card_acceptor: typing.Union['CardAcceptorModel', schemas.Unset] = schemas.unset,
        screening_score: typing.Union[MetaOapg.properties.screening_score, str, schemas.Unset] = schemas.unset,
        sender_data: typing.Union['OriginalCreditSenderData', schemas.Unset] = schemas.unset,
        transactionPurpose: typing.Union[MetaOapg.properties.transactionPurpose, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OriginalCreditRequestModel':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            mid=mid,
            type=type,
            card_id=card_id,
            card_acceptor=card_acceptor,
            screening_score=screening_score,
            sender_data=sender_data,
            transactionPurpose=transactionPurpose,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.card_acceptor_model import CardAcceptorModel
from synctera_client.model.original_credit_sender_data import OriginalCreditSenderData



from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.get import ApiForget
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.put import ApiForput


class CustomersCustomerIdWatchlistsSubscriptionsSubscriptionId(
    ApiForget,
    ApiForput,
):
    pass



from synctera_client.paths.customers_customer_id_disclosures.get import ApiForget
from synctera_client.paths.customers_customer_id_disclosures.post import ApiForpost


class CustomersCustomerIdDisclosures(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.accounts_products.get import ApiForget
from synctera_client.paths.accounts_products.post import ApiForpost


class AccountsProducts(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class OriginalCreditSenderData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "funding_source",
        }
        
        class properties:
            
            
            class funding_source(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "credit": "CREDIT",
                        "debit": "DEBIT",
                        "prepaid": "PREPAID",
                        "deposit_account": "DEPOSIT_ACCOUNT",
                        "cash": "CASH",
                        "mobile_money_payment": "MOBILE_MONEY_PAYMENT",
                        "non_visa_credit": "NON_VISA_CREDIT",
                    }
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("credit")
                
                @schemas.classproperty
                def DEBIT(cls):
                    return cls("debit")
                
                @schemas.classproperty
                def PREPAID(cls):
                    return cls("prepaid")
                
                @schemas.classproperty
                def DEPOSIT_ACCOUNT(cls):
                    return cls("deposit_account")
                
                @schemas.classproperty
                def CASH(cls):
                    return cls("cash")
                
                @schemas.classproperty
                def MOBILE_MONEY_PAYMENT(cls):
                    return cls("mobile_money_payment")
                
                @schemas.classproperty
                def NON_VISA_CREDIT(cls):
                    return cls("non_visa_credit")
            sender_account_number = schemas.StrSchema
            
            
            class sender_account_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "other": "OTHER",
                        "rtn_bank_account": "RTN_BANK_ACCOUNT",
                        "iban": "IBAN",
                        "card_account": "CARD_ACCOUNT",
                        "email": "EMAIL",
                        "phone_number": "PHONE_NUMBER",
                        "bank_account_number_and_identification_code": "BANK_ACCOUNT_NUMBER_AND_IDENTIFICATION_CODE",
                        "wallet_id": "WALLET_ID",
                        "social_network_id": "SOCIAL_NETWORK_ID",
                    }
                
                @schemas.classproperty
                def OTHER(cls):
                    return cls("other")
                
                @schemas.classproperty
                def RTN_BANK_ACCOUNT(cls):
                    return cls("rtn_bank_account")
                
                @schemas.classproperty
                def IBAN(cls):
                    return cls("iban")
                
                @schemas.classproperty
                def CARD_ACCOUNT(cls):
                    return cls("card_account")
                
                @schemas.classproperty
                def EMAIL(cls):
                    return cls("email")
                
                @schemas.classproperty
                def PHONE_NUMBER(cls):
                    return cls("phone_number")
                
                @schemas.classproperty
                def BANK_ACCOUNT_NUMBER_AND_IDENTIFICATION_CODE(cls):
                    return cls("bank_account_number_and_identification_code")
                
                @schemas.classproperty
                def WALLET_ID(cls):
                    return cls("wallet_id")
                
                @schemas.classproperty
                def SOCIAL_NETWORK_ID(cls):
                    return cls("social_network_id")
            sender_address = schemas.StrSchema
            sender_city = schemas.StrSchema
            sender_country = schemas.StrSchema
            sender_name = schemas.StrSchema
            sender_reference_number = schemas.StrSchema
            sender_state = schemas.StrSchema
            
            
            class transaction_purpose(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "family_support": "FAMILY_SUPPORT",
                        "labor_transfers": "LABOR_TRANSFERS",
                        "travel": "TRAVEL",
                        "education": "EDUCATION",
                        "medical_treatment": "MEDICAL_TREATMENT",
                        "emergency_need": "EMERGENCY_NEED",
                        "savings": "SAVINGS",
                        "gifts": "GIFTS",
                        "other": "OTHER",
                        "salary": "SALARY",
                        "lending": "LENDING",
                        "crypto_currency": "CRYPTO_CURRENCY",
                    }
                
                @schemas.classproperty
                def FAMILY_SUPPORT(cls):
                    return cls("family_support")
                
                @schemas.classproperty
                def LABOR_TRANSFERS(cls):
                    return cls("labor_transfers")
                
                @schemas.classproperty
                def TRAVEL(cls):
                    return cls("travel")
                
                @schemas.classproperty
                def EDUCATION(cls):
                    return cls("education")
                
                @schemas.classproperty
                def MEDICAL_TREATMENT(cls):
                    return cls("medical_treatment")
                
                @schemas.classproperty
                def EMERGENCY_NEED(cls):
                    return cls("emergency_need")
                
                @schemas.classproperty
                def SAVINGS(cls):
                    return cls("savings")
                
                @schemas.classproperty
                def GIFTS(cls):
                    return cls("gifts")
                
                @schemas.classproperty
                def OTHER(cls):
                    return cls("other")
                
                @schemas.classproperty
                def SALARY(cls):
                    return cls("salary")
                
                @schemas.classproperty
                def LENDING(cls):
                    return cls("lending")
                
                @schemas.classproperty
                def CRYPTO_CURRENCY(cls):
                    return cls("crypto_currency")
            
            
            class unique_transaction_reference_number(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 17
                    min_length = 1
            __annotations__ = {
                "funding_source": funding_source,
                "sender_account_number": sender_account_number,
                "sender_account_type": sender_account_type,
                "sender_address": sender_address,
                "sender_city": sender_city,
                "sender_country": sender_country,
                "sender_name": sender_name,
                "sender_reference_number": sender_reference_number,
                "sender_state": sender_state,
                "transaction_purpose": transaction_purpose,
                "unique_transaction_reference_number": unique_transaction_reference_number,
            }
    
    funding_source: MetaOapg.properties.funding_source
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["funding_source"]) -> MetaOapg.properties.funding_source: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_account_number"]) -> MetaOapg.properties.sender_account_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_account_type"]) -> MetaOapg.properties.sender_account_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_address"]) -> MetaOapg.properties.sender_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_city"]) -> MetaOapg.properties.sender_city: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_country"]) -> MetaOapg.properties.sender_country: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_name"]) -> MetaOapg.properties.sender_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_reference_number"]) -> MetaOapg.properties.sender_reference_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender_state"]) -> MetaOapg.properties.sender_state: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_purpose"]) -> MetaOapg.properties.transaction_purpose: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["unique_transaction_reference_number"]) -> MetaOapg.properties.unique_transaction_reference_number: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["funding_source", "sender_account_number", "sender_account_type", "sender_address", "sender_city", "sender_country", "sender_name", "sender_reference_number", "sender_state", "transaction_purpose", "unique_transaction_reference_number", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["funding_source"]) -> MetaOapg.properties.funding_source: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_account_number"]) -> typing.Union[MetaOapg.properties.sender_account_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_account_type"]) -> typing.Union[MetaOapg.properties.sender_account_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_address"]) -> typing.Union[MetaOapg.properties.sender_address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_city"]) -> typing.Union[MetaOapg.properties.sender_city, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_country"]) -> typing.Union[MetaOapg.properties.sender_country, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_name"]) -> typing.Union[MetaOapg.properties.sender_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_reference_number"]) -> typing.Union[MetaOapg.properties.sender_reference_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender_state"]) -> typing.Union[MetaOapg.properties.sender_state, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_purpose"]) -> typing.Union[MetaOapg.properties.transaction_purpose, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["unique_transaction_reference_number"]) -> typing.Union[MetaOapg.properties.unique_transaction_reference_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["funding_source", "sender_account_number", "sender_account_type", "sender_address", "sender_city", "sender_country", "sender_name", "sender_reference_number", "sender_state", "transaction_purpose", "unique_transaction_reference_number", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        funding_source: typing.Union[MetaOapg.properties.funding_source, str, ],
        sender_account_number: typing.Union[MetaOapg.properties.sender_account_number, str, schemas.Unset] = schemas.unset,
        sender_account_type: typing.Union[MetaOapg.properties.sender_account_type, str, schemas.Unset] = schemas.unset,
        sender_address: typing.Union[MetaOapg.properties.sender_address, str, schemas.Unset] = schemas.unset,
        sender_city: typing.Union[MetaOapg.properties.sender_city, str, schemas.Unset] = schemas.unset,
        sender_country: typing.Union[MetaOapg.properties.sender_country, str, schemas.Unset] = schemas.unset,
        sender_name: typing.Union[MetaOapg.properties.sender_name, str, schemas.Unset] = schemas.unset,
        sender_reference_number: typing.Union[MetaOapg.properties.sender_reference_number, str, schemas.Unset] = schemas.unset,
        sender_state: typing.Union[MetaOapg.properties.sender_state, str, schemas.Unset] = schemas.unset,
        transaction_purpose: typing.Union[MetaOapg.properties.transaction_purpose, str, schemas.Unset] = schemas.unset,
        unique_transaction_reference_number: typing.Union[MetaOapg.properties.unique_transaction_reference_number, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OriginalCreditSenderData':
        return super().__new__(
            cls,
            *_args,
            funding_source=funding_source,
            sender_account_number=sender_account_number,
            sender_account_type=sender_account_type,
            sender_address=sender_address,
            sender_city=sender_city,
            sender_country=sender_country,
            sender_name=sender_name,
            sender_reference_number=sender_reference_number,
            sender_state=sender_state,
            transaction_purpose=transaction_purpose,
            unique_transaction_reference_number=unique_transaction_reference_number,
            _configuration=_configuration,
            **kwargs,
        )



from synctera_client.paths.spend_controls_spend_control_id.get import ApiForget
from synctera_client.paths.spend_controls_spend_control_id.patch import ApiForpatch


class SpendControlsSpendControlId(
    ApiForget,
    ApiForpatch,
):
    pass



from synctera_client.paths.ach_transaction_id.get import ApiForget
from synctera_client.paths.ach_transaction_id.patch import ApiForpatch


class AchTransactionId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.32.0.dev6
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ReturnAch(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Regular return
    """


    class MetaOapg:
        required = {
            "type",
        }
        
        class properties:
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def INSUFFICIENT_FUNDS(cls):
                    return cls("insufficient_funds")
                
                @schemas.classproperty
                def ACC_CLOSED(cls):
                    return cls("acc_closed")
                
                @schemas.classproperty
                def ACC_NOT_FOUND(cls):
                    return cls("acc_not_found")
                
                @schemas.classproperty
                def ACC_INVALID(cls):
                    return cls("acc_invalid")
                
                @schemas.classproperty
                def UNAUTHORIZED_CORP_DEBIT(cls):
                    return cls("unauthorized_corp_debit")
                
                @schemas.classproperty
                def RETURN_REQUESTED(cls):
                    return cls("return_requested")
                
                @schemas.classproperty
                def AUTH_REVOKED(cls):
                    return cls("auth_revoked")
                
                @schemas.classproperty
                def PAYMENT_STOPPED(cls):
                    return cls("payment_stopped")
                
                @schemas.classproperty
                def UNCOLLECTED_FUNDS(cls):
                    return cls("uncollected_funds")
                
                @schemas.classproperty
                def UNAUTHORIZED_DEBIT(cls):
                    return cls("unauthorized_debit")
                
                @schemas.classproperty
                def FAILED_TERMS(cls):
                    return cls("failed_terms")
                
                @schemas.classproperty
                def ACCOUNT_SOLD(cls):
                    return cls("account_sold")
                
                @schemas.classproperty
                def ACC_FROZEN(cls):
                    return cls("acc_frozen")
                
                @schemas.classproperty
                def FIELDS_NOT_PROCESSABLE(cls):
                    return cls("fields_not_processable")
                
                @schemas.classproperty
                def IMPROPER_EFFECTIVE_DATE(cls):
                    return cls("improper_effective_date")
                
                @schemas.classproperty
                def NON_TRANSACTION_ACCOUNT(cls):
                    return cls("non_transaction_account")
                
                @schemas.classproperty
                def CREDIT_REFUSED(cls):
                    return cls("credit_refused")
                
                @schemas.classproperty
                def DUPLICATE_TRANSACTION(cls):
                    return cls("duplicate_transaction")
                
                @schemas.classproperty
                def CORP_RECEIVER_UNAUTHORIZED(cls):
                    return cls("corp_receiver_unauthorized")
                
                @schemas.classproperty
                def PERMISSIBLE_RETURN(cls):
                    return cls("permissible_return")
                
                @schemas.classproperty
                def SOURCE_DOCUMENT_PRESENTED(cls):
                    return cls("source_document_presented")
                
                @schemas.classproperty
                def SOURCE_DOCUMENT_STOP_PAYMENT(cls):
                    return cls("source_document_stop_payment")
                
                @schemas.classproperty
                def IMPROPER_SOURCE_DOCUMENT(cls):
                    return cls("improper_source_document")
                
                @schemas.classproperty
                def STATE_LAW_AFFECTING_ACCEPTANCE(cls):
                    return cls("state_law_affecting_acceptance")
                
                @schemas.classproperty
                def INELIGIBLE_OR_IMPROPER_ENTRY(cls):
                    return cls("ineligible_or_improper_entry")
                
                @schemas.classproperty
                def ITEM_STOP_PAYMENT(cls):
                    return cls("item_stop_payment")
            __annotations__ = {
                "type": type,
            }
    
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ReturnAch':
        return super().__new__(
            cls,
            *_args,
            type=type,
            _configuration=_configuration,
            **kwargs,
        )



from synctera_client.paths.transactions_internal_transfer_id.get import ApiForget
from synctera_client.paths.transactions_internal_transfer_id.patch import ApiForpatch


class TransactionsInternalTransferId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class BasePerson(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def ban_status() -> typing.Type['BanStatus']:
                return BanStatus
            creation_time = schemas.DateTimeSchema
            email = schemas.StrSchema
            id = schemas.UUIDSchema
            kyc_exempt = schemas.BoolSchema
            kyc_last_run = schemas.DateTimeSchema
        
            @staticmethod
            def kyc_status() -> typing.Type['CustomerKycStatus']:
                return CustomerKycStatus
            last_updated_time = schemas.DateTimeSchema
        
            @staticmethod
            def legal_address() -> typing.Type['Address']:
                return Address
            metadata = schemas.DictSchema
            middle_name = schemas.StrSchema
            note = schemas.StrSchema
            
            
            class phone_number(
                schemas.StrSchema
            ):
                pass
            
            
            class related_customers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Relationship1']:
                        return Relationship1
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Relationship1'], typing.List['Relationship1']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'related_customers':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Relationship1':
                    return super().__getitem__(i)
        
            @staticmethod
            def shipping_address() -> typing.Type['Address']:
                return Address
            ssn = schemas.StrSchema
        
            @staticmethod
            def ssn_source() -> typing.Type['SsnSource']:
                return SsnSource
            tenant = schemas.StrSchema
            __annotations__ = {
                "ban_status": ban_status,
                "creation_time": creation_time,
                "email": email,
                "id": id,
                "kyc_exempt": kyc_exempt,
                "kyc_last_run": kyc_last_run,
                "kyc_status": kyc_status,
                "last_updated_time": last_updated_time,
                "legal_address": legal_address,
                "metadata": metadata,
                "middle_name": middle_name,
                "note": note,
                "phone_number": phone_number,
                "related_customers": related_customers,
                "shipping_address": shipping_address,
                "ssn": ssn,
                "ssn_source": ssn_source,
                "tenant": tenant,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ban_status"]) -> 'BanStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["kyc_exempt"]) -> MetaOapg.properties.kyc_exempt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["kyc_last_run"]) -> MetaOapg.properties.kyc_last_run: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["kyc_status"]) -> 'CustomerKycStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["legal_address"]) -> 'Address': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["middle_name"]) -> MetaOapg.properties.middle_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["note"]) -> MetaOapg.properties.note: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone_number"]) -> MetaOapg.properties.phone_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["related_customers"]) -> MetaOapg.properties.related_customers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["shipping_address"]) -> 'Address': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ssn"]) -> MetaOapg.properties.ssn: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ssn_source"]) -> 'SsnSource': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ban_status", "creation_time", "email", "id", "kyc_exempt", "kyc_last_run", "kyc_status", "last_updated_time", "legal_address", "metadata", "middle_name", "note", "phone_number", "related_customers", "shipping_address", "ssn", "ssn_source", "tenant", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ban_status"]) -> typing.Union['BanStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> typing.Union[MetaOapg.properties.email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["kyc_exempt"]) -> typing.Union[MetaOapg.properties.kyc_exempt, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["kyc_last_run"]) -> typing.Union[MetaOapg.properties.kyc_last_run, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["kyc_status"]) -> typing.Union['CustomerKycStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> typing.Union[MetaOapg.properties.last_updated_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["legal_address"]) -> typing.Union['Address', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["middle_name"]) -> typing.Union[MetaOapg.properties.middle_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["note"]) -> typing.Union[MetaOapg.properties.note, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone_number"]) -> typing.Union[MetaOapg.properties.phone_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["related_customers"]) -> typing.Union[MetaOapg.properties.related_customers, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["shipping_address"]) -> typing.Union['Address', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ssn"]) -> typing.Union[MetaOapg.properties.ssn, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ssn_source"]) -> typing.Union['SsnSource', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tenant"]) -> typing.Union[MetaOapg.properties.tenant, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ban_status", "creation_time", "email", "id", "kyc_exempt", "kyc_last_run", "kyc_status", "last_updated_time", "legal_address", "metadata", "middle_name", "note", "phone_number", "related_customers", "shipping_address", "ssn", "ssn_source", "tenant", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        ban_status: typing.Union['BanStatus', schemas.Unset] = schemas.unset,
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
        email: typing.Union[MetaOapg.properties.email, str, schemas.Unset] = schemas.unset,
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        kyc_exempt: typing.Union[MetaOapg.properties.kyc_exempt, bool, schemas.Unset] = schemas.unset,
        kyc_last_run: typing.Union[MetaOapg.properties.kyc_last_run, str, datetime, schemas.Unset] = schemas.unset,
        kyc_status: typing.Union['CustomerKycStatus', schemas.Unset] = schemas.unset,
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, schemas.Unset] = schemas.unset,
        legal_address: typing.Union['Address', schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        middle_name: typing.Union[MetaOapg.properties.middle_name, str, schemas.Unset] = schemas.unset,
        note: typing.Union[MetaOapg.properties.note, str, schemas.Unset] = schemas.unset,
        phone_number: typing.Union[MetaOapg.properties.phone_number, str, schemas.Unset] = schemas.unset,
        related_customers: typing.Union[MetaOapg.properties.related_customers, list, tuple, schemas.Unset] = schemas.unset,
        shipping_address: typing.Union['Address', schemas.Unset] = schemas.unset,
        ssn: typing.Union[MetaOapg.properties.ssn, str, schemas.Unset] = schemas.unset,
        ssn_source: typing.Union['SsnSource', schemas.Unset] = schemas.unset,
        tenant: typing.Union[MetaOapg.properties.tenant, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BasePerson':
        return super().__new__(
            cls,
            *_args,
            ban_status=ban_status,
            creation_time=creation_time,
            email=email,
            id=id,
            kyc_exempt=kyc_exempt,
            kyc_last_run=kyc_last_run,
            kyc_status=kyc_status,
            last_updated_time=last_updated_time,
            legal_address=legal_address,
            metadata=metadata,
            middle_name=middle_name,
            note=note,
            phone_number=phone_number,
            related_customers=related_customers,
            shipping_address=shipping_address,
            ssn=ssn,
            ssn_source=ssn_source,
            tenant=tenant,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.address import Address
from synctera_client.model.ban_status import BanStatus
from synctera_client.model.customer_kyc_status import CustomerKycStatus
from synctera_client.model.relationship1 import Relationship1
from synctera_client.model.ssn_source import SsnSource



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class TransactionLine1(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "is_primary",
            "created",
            "related_line",
            "is_offset",
            "avail_balance",
            "available_balance",
            "account_no",
            "uuid",
            "network",
            "dc_sign",
            "account_id",
            "balance",
            "is_gl_acc",
            "meta",
            "currency",
            "updated",
            "seq",
            "tenant",
            "is_fee",
        }
        
        class properties:
            account_id = schemas.StrSchema
            account_no = schemas.StrSchema
            amount = schemas.Int64Schema
            avail_balance = schemas.Int64Schema
            available_balance = schemas.Int64Schema
            balance = schemas.Int64Schema
            created = schemas.DateTimeSchema
            currency = schemas.StrSchema
        
            @staticmethod
            def dc_sign() -> typing.Type['DcSign']:
                return DcSign
            is_fee = schemas.BoolSchema
            is_gl_acc = schemas.BoolSchema
            is_offset = schemas.BoolSchema
            is_primary = schemas.BoolSchema
            
            
            class meta(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'meta':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            network = schemas.StrSchema
            related_line = schemas.IntSchema
            seq = schemas.IntSchema
            tenant = schemas.StrSchema
            updated = schemas.DateTimeSchema
            uuid = schemas.UUIDSchema
            __annotations__ = {
                "account_id": account_id,
                "account_no": account_no,
                "amount": amount,
                "avail_balance": avail_balance,
                "available_balance": available_balance,
                "balance": balance,
                "created": created,
                "currency": currency,
                "dc_sign": dc_sign,
                "is_fee": is_fee,
                "is_gl_acc": is_gl_acc,
                "is_offset": is_offset,
                "is_primary": is_primary,
                "meta": meta,
                "network": network,
                "related_line": related_line,
                "seq": seq,
                "tenant": tenant,
                "updated": updated,
                "uuid": uuid,
            }
    
    amount: MetaOapg.properties.amount
    is_primary: MetaOapg.properties.is_primary
    created: MetaOapg.properties.created
    related_line: MetaOapg.properties.related_line
    is_offset: MetaOapg.properties.is_offset
    avail_balance: MetaOapg.properties.avail_balance
    available_balance: MetaOapg.properties.available_balance
    account_no: MetaOapg.properties.account_no
    uuid: MetaOapg.properties.uuid
    network: MetaOapg.properties.network
    dc_sign: 'DcSign'
    account_id: MetaOapg.properties.account_id
    balance: MetaOapg.properties.balance
    is_gl_acc: MetaOapg.properties.is_gl_acc
    meta: MetaOapg.properties.meta
    currency: MetaOapg.properties.currency
    updated: MetaOapg.properties.updated
    seq: MetaOapg.properties.seq
    tenant: MetaOapg.properties.tenant
    is_fee: MetaOapg.properties.is_fee
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_no"]) -> MetaOapg.properties.account_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["avail_balance"]) -> MetaOapg.properties.avail_balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["available_balance"]) -> MetaOapg.properties.available_balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_fee"]) -> MetaOapg.properties.is_fee: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_gl_acc"]) -> MetaOapg.properties.is_gl_acc: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_offset"]) -> MetaOapg.properties.is_offset: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_primary"]) -> MetaOapg.properties.is_primary: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["meta"]) -> MetaOapg.properties.meta: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["related_line"]) -> MetaOapg.properties.related_line: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["seq"]) -> MetaOapg.properties.seq: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated"]) -> MetaOapg.properties.updated: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["uuid"]) -> MetaOapg.properties.uuid: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_id", "account_no", "amount", "avail_balance", "available_balance", "balance", "created", "currency", "dc_sign", "is_fee", "is_gl_acc", "is_offset", "is_primary", "meta", "network", "related_line", "seq", "tenant", "updated", "uuid", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_no"]) -> MetaOapg.properties.account_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["avail_balance"]) -> MetaOapg.properties.avail_balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["available_balance"]) -> MetaOapg.properties.available_balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_fee"]) -> MetaOapg.properties.is_fee: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_gl_acc"]) -> MetaOapg.properties.is_gl_acc: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_offset"]) -> MetaOapg.properties.is_offset: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_primary"]) -> MetaOapg.properties.is_primary: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["meta"]) -> MetaOapg.properties.meta: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["related_line"]) -> MetaOapg.properties.related_line: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["seq"]) -> MetaOapg.properties.seq: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated"]) -> MetaOapg.properties.updated: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["uuid"]) -> MetaOapg.properties.uuid: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_id", "account_no", "amount", "avail_balance", "available_balance", "balance", "created", "currency", "dc_sign", "is_fee", "is_gl_acc", "is_offset", "is_primary", "meta", "network", "related_line", "seq", "tenant", "updated", "uuid", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        is_primary: typing.Union[MetaOapg.properties.is_primary, bool, ],
        created: typing.Union[MetaOapg.properties.created, str, datetime, ],
        related_line: typing.Union[MetaOapg.properties.related_line, decimal.Decimal, int, ],
        is_offset: typing.Union[MetaOapg.properties.is_offset, bool, ],
        avail_balance: typing.Union[MetaOapg.properties.avail_balance, decimal.Decimal, int, ],
        available_balance: typing.Union[MetaOapg.properties.available_balance, decimal.Decimal, int, ],
        account_no: typing.Union[MetaOapg.properties.account_no, str, ],
        uuid: typing.Union[MetaOapg.properties.uuid, str, uuid.UUID, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        dc_sign: 'DcSign',
        account_id: typing.Union[MetaOapg.properties.account_id, str, ],
        balance: typing.Union[MetaOapg.properties.balance, decimal.Decimal, int, ],
        is_gl_acc: typing.Union[MetaOapg.properties.is_gl_acc, bool, ],
        meta: typing.Union[MetaOapg.properties.meta, dict, frozendict.frozendict, None, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        updated: typing.Union[MetaOapg.properties.updated, str, datetime, ],
        seq: typing.Union[MetaOapg.properties.seq, decimal.Decimal, int, ],
        tenant: typing.Union[MetaOapg.properties.tenant, str, ],
        is_fee: typing.Union[MetaOapg.properties.is_fee, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TransactionLine1':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            is_primary=is_primary,
            created=created,
            related_line=related_line,
            is_offset=is_offset,
            avail_balance=avail_balance,
            available_balance=available_balance,
            account_no=account_no,
            uuid=uuid,
            network=network,
            dc_sign=dc_sign,
            account_id=account_id,
            balance=balance,
            is_gl_acc=is_gl_acc,
            meta=meta,
            currency=currency,
            updated=updated,
            seq=seq,
            tenant=tenant,
            is_fee=is_fee,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.dc_sign import DcSign



from synctera_client.paths.customers_customer_id_employment_employment_id.get import ApiForget
from synctera_client.paths.customers_customer_id_employment_employment_id.put import ApiForput


class CustomersCustomerIdEmploymentEmploymentId(
    ApiForget,
    ApiForput,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ExternalAccountVendorData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            account_number_mask = schemas.StrSchema
            institution_id = schemas.StrSchema
            __annotations__ = {
                "account_number_mask": account_number_mask,
                "institution_id": institution_id,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_number_mask"]) -> MetaOapg.properties.account_number_mask: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["institution_id"]) -> MetaOapg.properties.institution_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_number_mask", "institution_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_number_mask"]) -> typing.Union[MetaOapg.properties.account_number_mask, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["institution_id"]) -> typing.Union[MetaOapg.properties.institution_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_number_mask", "institution_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        account_number_mask: typing.Union[MetaOapg.properties.account_number_mask, str, schemas.Unset] = schemas.unset,
        institution_id: typing.Union[MetaOapg.properties.institution_id, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ExternalAccountVendorData':
        return super().__new__(
            cls,
            *_args,
            account_number_mask=account_number_mask,
            institution_id=institution_id,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class PendingTransactionHistoryData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "reason",
            "amount",
            "auto_post_at",
            "was_partial",
            "avail_balance",
            "idemkey",
            "memo",
            "available_balance",
            "type",
            "network",
            "dc_sign",
            "force_post",
            "expires_at",
            "balance",
            "subtype",
            "total_amount",
            "effective_date",
            "transaction_time",
            "currency",
            "req_amount",
            "operation",
            "status",
        }
        
        class properties:
            
            
            class amount(
                schemas.Int64Schema
            ):
            
            
                class MetaOapg:
                    format = 'int64'
                    inclusive_minimum = 0
            auto_post_at = schemas.DateTimeSchema
            avail_balance = schemas.Int64Schema
            available_balance = schemas.Int64Schema
            balance = schemas.Int64Schema
            currency = schemas.StrSchema
        
            @staticmethod
            def dc_sign() -> typing.Type['DcSign']:
                return DcSign
            effective_date = schemas.DateTimeSchema
            expires_at = schemas.DateTimeSchema
            force_post = schemas.BoolSchema
            idemkey = schemas.StrSchema
            memo = schemas.StrSchema
            network = schemas.StrSchema
            
            
            class operation(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "hold_new": "NEW",
                        "hold_increase": "INCREASE",
                        "hold_decrease": "DECREASE",
                        "hold_replace": "REPLACE",
                        "hold_decline": "DECLINE",
                        "hold_cancel": "CANCEL",
                        "hold_post": "POST",
                        "hold_expire": "EXPIRE",
                    }
                
                @schemas.classproperty
                def NEW(cls):
                    return cls("hold_new")
                
                @schemas.classproperty
                def INCREASE(cls):
                    return cls("hold_increase")
                
                @schemas.classproperty
                def DECREASE(cls):
                    return cls("hold_decrease")
                
                @schemas.classproperty
                def REPLACE(cls):
                    return cls("hold_replace")
                
                @schemas.classproperty
                def DECLINE(cls):
                    return cls("hold_decline")
                
                @schemas.classproperty
                def CANCEL(cls):
                    return cls("hold_cancel")
                
                @schemas.classproperty
                def POST(cls):
                    return cls("hold_post")
                
                @schemas.classproperty
                def EXPIRE(cls):
                    return cls("hold_expire")
            reason = schemas.StrSchema
            
            
            class req_amount(
                schemas.Int64Schema
            ):
            
            
                class MetaOapg:
                    format = 'int64'
                    inclusive_minimum = 0
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "PENDING": "PENDING",
                        "REPLACED": "REPLACED",
                        "DECLINED": "DECLINED",
                        "RELEASED": "RELEASED",
                        "PARTCLEARED": "PARTCLEARED",
                        "EXPIRED": "EXPIRED",
                        "CLEARED": "CLEARED",
                        "INTERNAL_ERROR": "INTERNAL_ERROR",
                    }
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def REPLACED(cls):
                    return cls("REPLACED")
                
                @schemas.classproperty
                def DECLINED(cls):
                    return cls("DECLINED")
                
                @schemas.classproperty
                def RELEASED(cls):
                    return cls("RELEASED")
                
                @schemas.classproperty
                def PARTCLEARED(cls):
                    return cls("PARTCLEARED")
                
                @schemas.classproperty
                def EXPIRED(cls):
                    return cls("EXPIRED")
                
                @schemas.classproperty
                def CLEARED(cls):
                    return cls("CLEARED")
                
                @schemas.classproperty
                def INTERNAL_ERROR(cls):
                    return cls("INTERNAL_ERROR")
            subtype = schemas.StrSchema
            
            
            class total_amount(
                schemas.Int64Schema
            ):
            
            
                class MetaOapg:
                    format = 'int64'
                    inclusive_minimum = 0
            transaction_time = schemas.DateTimeSchema
            type = schemas.StrSchema
            was_partial = schemas.BoolSchema
            
            
            class external_data(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'external_data':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class risk_info(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'risk_info':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            transaction_id = schemas.UUIDSchema
            
            
            class user_data(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'user_data':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "amount": amount,
                "auto_post_at": auto_post_at,
                "avail_balance": avail_balance,
                "available_balance": available_balance,
                "balance": balance,
                "currency": currency,
                "dc_sign": dc_sign,
                "effective_date": effective_date,
                "expires_at": expires_at,
                "force_post": force_post,
                "idemkey": idemkey,
                "memo": memo,
                "network": network,
                "operation": operation,
                "reason": reason,
                "req_amount": req_amount,
                "status": status,
                "subtype": subtype,
                "total_amount": total_amount,
                "transaction_time": transaction_time,
                "type": type,
                "was_partial": was_partial,
                "external_data": external_data,
                "risk_info": risk_info,
                "transaction_id": transaction_id,
                "user_data": user_data,
            }
    
    reason: MetaOapg.properties.reason
    amount: MetaOapg.properties.amount
    auto_post_at: MetaOapg.properties.auto_post_at
    was_partial: MetaOapg.properties.was_partial
    avail_balance: MetaOapg.properties.avail_balance
    idemkey: MetaOapg.properties.idemkey
    memo: MetaOapg.properties.memo
    available_balance: MetaOapg.properties.available_balance
    type: MetaOapg.properties.type
    network: MetaOapg.properties.network
    dc_sign: 'DcSign'
    force_post: MetaOapg.properties.force_post
    expires_at: MetaOapg.properties.expires_at
    balance: MetaOapg.properties.balance
    subtype: MetaOapg.properties.subtype
    total_amount: MetaOapg.properties.total_amount
    effective_date: MetaOapg.properties.effective_date
    transaction_time: MetaOapg.properties.transaction_time
    currency: MetaOapg.properties.currency
    req_amount: MetaOapg.properties.req_amount
    operation: MetaOapg.properties.operation
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["auto_post_at"]) -> MetaOapg.properties.auto_post_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["avail_balance"]) -> MetaOapg.properties.avail_balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["available_balance"]) -> MetaOapg.properties.available_balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expires_at"]) -> MetaOapg.properties.expires_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idemkey"]) -> MetaOapg.properties.idemkey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operation"]) -> MetaOapg.properties.operation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["req_amount"]) -> MetaOapg.properties.req_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total_amount"]) -> MetaOapg.properties.total_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["was_partial"]) -> MetaOapg.properties.was_partial: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["external_data"]) -> MetaOapg.properties.external_data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["risk_info"]) -> MetaOapg.properties.risk_info: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_data"]) -> MetaOapg.properties.user_data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "auto_post_at", "avail_balance", "available_balance", "balance", "currency", "dc_sign", "effective_date", "expires_at", "force_post", "idemkey", "memo", "network", "operation", "reason", "req_amount", "status", "subtype", "total_amount", "transaction_time", "type", "was_partial", "external_data", "risk_info", "transaction_id", "user_data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["auto_post_at"]) -> MetaOapg.properties.auto_post_at: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["avail_balance"]) -> MetaOapg.properties.avail_balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["available_balance"]) -> MetaOapg.properties.available_balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dc_sign"]) -> 'DcSign': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effective_date"]) -> MetaOapg.properties.effective_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expires_at"]) -> MetaOapg.properties.expires_at: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["force_post"]) -> MetaOapg.properties.force_post: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idemkey"]) -> MetaOapg.properties.idemkey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operation"]) -> MetaOapg.properties.operation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["req_amount"]) -> MetaOapg.properties.req_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["subtype"]) -> MetaOapg.properties.subtype: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total_amount"]) -> MetaOapg.properties.total_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_time"]) -> MetaOapg.properties.transaction_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["was_partial"]) -> MetaOapg.properties.was_partial: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["external_data"]) -> typing.Union[MetaOapg.properties.external_data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["risk_info"]) -> typing.Union[MetaOapg.properties.risk_info, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_id"]) -> typing.Union[MetaOapg.properties.transaction_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_data"]) -> typing.Union[MetaOapg.properties.user_data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "auto_post_at", "avail_balance", "available_balance", "balance", "currency", "dc_sign", "effective_date", "expires_at", "force_post", "idemkey", "memo", "network", "operation", "reason", "req_amount", "status", "subtype", "total_amount", "transaction_time", "type", "was_partial", "external_data", "risk_info", "transaction_id", "user_data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        reason: typing.Union[MetaOapg.properties.reason, str, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        auto_post_at: typing.Union[MetaOapg.properties.auto_post_at, str, datetime, ],
        was_partial: typing.Union[MetaOapg.properties.was_partial, bool, ],
        avail_balance: typing.Union[MetaOapg.properties.avail_balance, decimal.Decimal, int, ],
        idemkey: typing.Union[MetaOapg.properties.idemkey, str, ],
        memo: typing.Union[MetaOapg.properties.memo, str, ],
        available_balance: typing.Union[MetaOapg.properties.available_balance, decimal.Decimal, int, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        dc_sign: 'DcSign',
        force_post: typing.Union[MetaOapg.properties.force_post, bool, ],
        expires_at: typing.Union[MetaOapg.properties.expires_at, str, datetime, ],
        balance: typing.Union[MetaOapg.properties.balance, decimal.Decimal, int, ],
        subtype: typing.Union[MetaOapg.properties.subtype, str, ],
        total_amount: typing.Union[MetaOapg.properties.total_amount, decimal.Decimal, int, ],
        effective_date: typing.Union[MetaOapg.properties.effective_date, str, datetime, ],
        transaction_time: typing.Union[MetaOapg.properties.transaction_time, str, datetime, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        req_amount: typing.Union[MetaOapg.properties.req_amount, decimal.Decimal, int, ],
        operation: typing.Union[MetaOapg.properties.operation, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        external_data: typing.Union[MetaOapg.properties.external_data, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        risk_info: typing.Union[MetaOapg.properties.risk_info, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        transaction_id: typing.Union[MetaOapg.properties.transaction_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        user_data: typing.Union[MetaOapg.properties.user_data, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PendingTransactionHistoryData':
        return super().__new__(
            cls,
            *_args,
            reason=reason,
            amount=amount,
            auto_post_at=auto_post_at,
            was_partial=was_partial,
            avail_balance=avail_balance,
            idemkey=idemkey,
            memo=memo,
            available_balance=available_balance,
            type=type,
            network=network,
            dc_sign=dc_sign,
            force_post=force_post,
            expires_at=expires_at,
            balance=balance,
            subtype=subtype,
            total_amount=total_amount,
            effective_date=effective_date,
            transaction_time=transaction_time,
            currency=currency,
            req_amount=req_amount,
            operation=operation,
            status=status,
            external_data=external_data,
            risk_info=risk_info,
            transaction_id=transaction_id,
            user_data=user_data,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.dc_sign import DcSign



# coding: utf-8

# flake8: noqa

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from synctera_client.api_client import ApiClient

# import Configuration
from synctera_client.configuration import Configuration

# import exceptions
from synctera_client.exceptions import OpenApiException
from synctera_client.exceptions import ApiAttributeError
from synctera_client.exceptions import ApiTypeError
from synctera_client.exceptions import ApiValueError
from synctera_client.exceptions import ApiKeyError
from synctera_client.exceptions import ApiException



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.paths.spend_controls_spend_control_id import Api

from synctera_client.paths import PathValues

path = PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID


from synctera_client.paths.internal_accounts_internal_account_id.get import ApiForget
from synctera_client.paths.internal_accounts_internal_account_id.patch import ApiForpatch


class InternalAccountsInternalAccountId(
    ApiForget,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class AddAccountsRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "customer_type",
            "routing_identifiers",
            "account_owner_names",
            "type",
            "account_identifiers",
        }
        
        class properties:
        
            @staticmethod
            def account_identifiers() -> typing.Type['AddAccountsRequestAccountIdentifiers']:
                return AddAccountsRequestAccountIdentifiers
            
            
            class account_owner_names(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.StrSchema
                    ):
                        pass
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'account_owner_names':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def customer_type() -> typing.Type['ExtAccountCustomerType']:
                return ExtAccountCustomerType
        
            @staticmethod
            def routing_identifiers() -> typing.Type['AddAccountsRequestRoutingIdentifiers']:
                return AddAccountsRequestRoutingIdentifiers
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CHECKING(cls):
                    return cls("CHECKING")
                
                @schemas.classproperty
                def SAVINGS(cls):
                    return cls("SAVINGS")
            business_id = schemas.UUIDSchema
            customer_id = schemas.UUIDSchema
            metadata = schemas.DictSchema
            
            
            class nickname(
                schemas.StrSchema
            ):
                pass
            
            
            class vendor_account_id(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def verification() -> typing.Type['AccountVerification']:
                return AccountVerification
            __annotations__ = {
                "account_identifiers": account_identifiers,
                "account_owner_names": account_owner_names,
                "customer_type": customer_type,
                "routing_identifiers": routing_identifiers,
                "type": type,
                "business_id": business_id,
                "customer_id": customer_id,
                "metadata": metadata,
                "nickname": nickname,
                "vendor_account_id": vendor_account_id,
                "verification": verification,
            }
    
    customer_type: 'ExtAccountCustomerType'
    routing_identifiers: 'AddAccountsRequestRoutingIdentifiers'
    account_owner_names: MetaOapg.properties.account_owner_names
    type: MetaOapg.properties.type
    account_identifiers: 'AddAccountsRequestAccountIdentifiers'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_identifiers"]) -> 'AddAccountsRequestAccountIdentifiers': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_owner_names"]) -> MetaOapg.properties.account_owner_names: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_type"]) -> 'ExtAccountCustomerType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["routing_identifiers"]) -> 'AddAccountsRequestRoutingIdentifiers': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_id"]) -> MetaOapg.properties.business_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nickname"]) -> MetaOapg.properties.nickname: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_account_id"]) -> MetaOapg.properties.vendor_account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verification"]) -> 'AccountVerification': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_identifiers", "account_owner_names", "customer_type", "routing_identifiers", "type", "business_id", "customer_id", "metadata", "nickname", "vendor_account_id", "verification", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_identifiers"]) -> 'AddAccountsRequestAccountIdentifiers': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_owner_names"]) -> MetaOapg.properties.account_owner_names: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_type"]) -> 'ExtAccountCustomerType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["routing_identifiers"]) -> 'AddAccountsRequestRoutingIdentifiers': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_id"]) -> typing.Union[MetaOapg.properties.business_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> typing.Union[MetaOapg.properties.customer_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nickname"]) -> typing.Union[MetaOapg.properties.nickname, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_account_id"]) -> typing.Union[MetaOapg.properties.vendor_account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verification"]) -> typing.Union['AccountVerification', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_identifiers", "account_owner_names", "customer_type", "routing_identifiers", "type", "business_id", "customer_id", "metadata", "nickname", "vendor_account_id", "verification", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        customer_type: 'ExtAccountCustomerType',
        routing_identifiers: 'AddAccountsRequestRoutingIdentifiers',
        account_owner_names: typing.Union[MetaOapg.properties.account_owner_names, list, tuple, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        account_identifiers: 'AddAccountsRequestAccountIdentifiers',
        business_id: typing.Union[MetaOapg.properties.business_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        nickname: typing.Union[MetaOapg.properties.nickname, str, schemas.Unset] = schemas.unset,
        vendor_account_id: typing.Union[MetaOapg.properties.vendor_account_id, str, schemas.Unset] = schemas.unset,
        verification: typing.Union['AccountVerification', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AddAccountsRequest':
        return super().__new__(
            cls,
            *_args,
            customer_type=customer_type,
            routing_identifiers=routing_identifiers,
            account_owner_names=account_owner_names,
            type=type,
            account_identifiers=account_identifiers,
            business_id=business_id,
            customer_id=customer_id,
            metadata=metadata,
            nickname=nickname,
            vendor_account_id=vendor_account_id,
            verification=verification,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.account_verification import AccountVerification
from synctera_client.model.add_accounts_request_account_identifiers import AddAccountsRequestAccountIdentifiers
from synctera_client.model.add_accounts_request_routing_identifiers import AddAccountsRequestRoutingIdentifiers
from synctera_client.model.ext_account_customer_type import ExtAccountCustomerType



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Deposit(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Deposit using remote deposit capture
    """


    class MetaOapg:
        required = {
            "transaction_id",
            "deposit_amount",
            "account_id",
            "back_image_id",
            "deposit_currency",
            "front_image_id",
            "date_captured",
            "check_amount",
            "id",
            "date_processed",
            "vendor_info",
            "status",
        }
        
        class properties:
            account_id = schemas.UUIDSchema
            back_image_id = schemas.UUIDSchema
            
            
            class check_amount(
                schemas.IntSchema
            ):
                pass
            date_captured = schemas.DateTimeSchema
            date_processed = schemas.DateTimeSchema
            deposit_amount = schemas.IntSchema
            deposit_currency = schemas.StrSchema
            front_image_id = schemas.UUIDSchema
            id = schemas.UUIDSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def SUBMITTED(cls):
                    return cls("SUBMITTED")
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("FAILED")
                
                @schemas.classproperty
                def REJECTED(cls):
                    return cls("REJECTED")
            transaction_id = schemas.UUIDSchema
        
            @staticmethod
            def vendor_info() -> typing.Type['VendorInfo1']:
                return VendorInfo1
            business_id = schemas.UUIDSchema
            creation_time = schemas.DateTimeSchema
            last_updated_time = schemas.DateTimeSchema
            metadata = schemas.DictSchema
            ocr_account_number = schemas.StrSchema
            ocr_check_number = schemas.StrSchema
            ocr_routing_number = schemas.StrSchema
            person_id = schemas.UUIDSchema
            __annotations__ = {
                "account_id": account_id,
                "back_image_id": back_image_id,
                "check_amount": check_amount,
                "date_captured": date_captured,
                "date_processed": date_processed,
                "deposit_amount": deposit_amount,
                "deposit_currency": deposit_currency,
                "front_image_id": front_image_id,
                "id": id,
                "status": status,
                "transaction_id": transaction_id,
                "vendor_info": vendor_info,
                "business_id": business_id,
                "creation_time": creation_time,
                "last_updated_time": last_updated_time,
                "metadata": metadata,
                "ocr_account_number": ocr_account_number,
                "ocr_check_number": ocr_check_number,
                "ocr_routing_number": ocr_routing_number,
                "person_id": person_id,
            }
    
    transaction_id: MetaOapg.properties.transaction_id
    deposit_amount: MetaOapg.properties.deposit_amount
    account_id: MetaOapg.properties.account_id
    back_image_id: MetaOapg.properties.back_image_id
    deposit_currency: MetaOapg.properties.deposit_currency
    front_image_id: MetaOapg.properties.front_image_id
    date_captured: MetaOapg.properties.date_captured
    check_amount: MetaOapg.properties.check_amount
    id: MetaOapg.properties.id
    date_processed: MetaOapg.properties.date_processed
    vendor_info: 'VendorInfo1'
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["back_image_id"]) -> MetaOapg.properties.back_image_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["check_amount"]) -> MetaOapg.properties.check_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["date_captured"]) -> MetaOapg.properties.date_captured: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["date_processed"]) -> MetaOapg.properties.date_processed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["deposit_amount"]) -> MetaOapg.properties.deposit_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["deposit_currency"]) -> MetaOapg.properties.deposit_currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["front_image_id"]) -> MetaOapg.properties.front_image_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_info"]) -> 'VendorInfo1': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_id"]) -> MetaOapg.properties.business_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr_account_number"]) -> MetaOapg.properties.ocr_account_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr_check_number"]) -> MetaOapg.properties.ocr_check_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr_routing_number"]) -> MetaOapg.properties.ocr_routing_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["person_id"]) -> MetaOapg.properties.person_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_id", "back_image_id", "check_amount", "date_captured", "date_processed", "deposit_amount", "deposit_currency", "front_image_id", "id", "status", "transaction_id", "vendor_info", "business_id", "creation_time", "last_updated_time", "metadata", "ocr_account_number", "ocr_check_number", "ocr_routing_number", "person_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["back_image_id"]) -> MetaOapg.properties.back_image_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["check_amount"]) -> MetaOapg.properties.check_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["date_captured"]) -> MetaOapg.properties.date_captured: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["date_processed"]) -> MetaOapg.properties.date_processed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["deposit_amount"]) -> MetaOapg.properties.deposit_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["deposit_currency"]) -> MetaOapg.properties.deposit_currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["front_image_id"]) -> MetaOapg.properties.front_image_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_info"]) -> 'VendorInfo1': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_id"]) -> typing.Union[MetaOapg.properties.business_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> typing.Union[MetaOapg.properties.last_updated_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr_account_number"]) -> typing.Union[MetaOapg.properties.ocr_account_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr_check_number"]) -> typing.Union[MetaOapg.properties.ocr_check_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr_routing_number"]) -> typing.Union[MetaOapg.properties.ocr_routing_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["person_id"]) -> typing.Union[MetaOapg.properties.person_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_id", "back_image_id", "check_amount", "date_captured", "date_processed", "deposit_amount", "deposit_currency", "front_image_id", "id", "status", "transaction_id", "vendor_info", "business_id", "creation_time", "last_updated_time", "metadata", "ocr_account_number", "ocr_check_number", "ocr_routing_number", "person_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        transaction_id: typing.Union[MetaOapg.properties.transaction_id, str, uuid.UUID, ],
        deposit_amount: typing.Union[MetaOapg.properties.deposit_amount, decimal.Decimal, int, ],
        account_id: typing.Union[MetaOapg.properties.account_id, str, uuid.UUID, ],
        back_image_id: typing.Union[MetaOapg.properties.back_image_id, str, uuid.UUID, ],
        deposit_currency: typing.Union[MetaOapg.properties.deposit_currency, str, ],
        front_image_id: typing.Union[MetaOapg.properties.front_image_id, str, uuid.UUID, ],
        date_captured: typing.Union[MetaOapg.properties.date_captured, str, datetime, ],
        check_amount: typing.Union[MetaOapg.properties.check_amount, decimal.Decimal, int, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        date_processed: typing.Union[MetaOapg.properties.date_processed, str, datetime, ],
        vendor_info: 'VendorInfo1',
        status: typing.Union[MetaOapg.properties.status, str, ],
        business_id: typing.Union[MetaOapg.properties.business_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        ocr_account_number: typing.Union[MetaOapg.properties.ocr_account_number, str, schemas.Unset] = schemas.unset,
        ocr_check_number: typing.Union[MetaOapg.properties.ocr_check_number, str, schemas.Unset] = schemas.unset,
        ocr_routing_number: typing.Union[MetaOapg.properties.ocr_routing_number, str, schemas.Unset] = schemas.unset,
        person_id: typing.Union[MetaOapg.properties.person_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Deposit':
        return super().__new__(
            cls,
            *_args,
            transaction_id=transaction_id,
            deposit_amount=deposit_amount,
            account_id=account_id,
            back_image_id=back_image_id,
            deposit_currency=deposit_currency,
            front_image_id=front_image_id,
            date_captured=date_captured,
            check_amount=check_amount,
            id=id,
            date_processed=date_processed,
            vendor_info=vendor_info,
            status=status,
            business_id=business_id,
            creation_time=creation_time,
            last_updated_time=last_updated_time,
            metadata=metadata,
            ocr_account_number=ocr_account_number,
            ocr_check_number=ocr_check_number,
            ocr_routing_number=ocr_routing_number,
            person_id=person_id,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.vendor_info1 import VendorInfo1



from synctera_client.paths.accounts_account_id_relationships.get import ApiForget
from synctera_client.paths.accounts_account_id_relationships.post import ApiForpost


class AccountsAccountIdRelationships(
    ApiForget,
    ApiForpost,
):
    pass
